[![Documentation Status](https://readthedocs.org/projects/remote-mole/badge/?version=latest)](https://remote-mole.readthedocs.io/en/latest/)
[![pipeline](https://gitlab.com/acesrg/remote-ninja/badges/master/pipeline.svg)](https://gitlab.com/acesrg/remote-ninja/-/commits/master)
[![coverage](https://gitlab.com/acesrg/remote-ninja/badges/master/coverage.svg)](https://gitlab.com/acesrg/remote-ninja/-/jobs/artifacts/master/file/htmlcov/index.html?job=unittest)

# Discord bot (mole) generator to creates ngrok tunnels

read the docs!
